package cz.zcu.kiv.opencms.springmvcapp.controllers;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.opencms.main.CmsLog;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.Controller;

import cz.zcu.kiv.db.model.osoby.Osoba;
import cz.zcu.kiv.opencms.springmvcapp.services.OsobaManager;

/**
 * Controller pro mazani osoby
 * 
 *
 */
public class SmazOsobuController implements Controller{

	/**
	 * Logger
	 */
	protected final Log logger = CmsLog.getLog(this.getClass());

	private final String OSOBA_ID_PARAM = "id";
	
	private final String OSOBA_CONFIRM_PARAM = "confirm";

	/**
	 * Manager osob. Obsahuje operace provadene nad jednou nebo vice osobami. O inicializovani
	 * teto promenne se stara Spring a jeho IOC. 
	 */
	private OsobaManager osobaManager;

	/**
	 * Metoda obsluhujici pozadavek klienta.
	 * 
	 * @param request http request
	 * @param response http response
	 * @return tridu ModelAndView - obsahuje data, ktera budou zobrazena na webove strance a jmeno modelu, ktery
	 * se pouzije pro zobrazeni techto dat
	 * @throws Exception
	 */
	@Override
	public ModelAndView handleRequest(HttpServletRequest request, HttpServletResponse response) throws Exception {

		logger.info("Nacitam parametr z url");

		// nacte parametr id z http requestu
		String id = request.getParameter(OSOBA_ID_PARAM);
		
		// nacte parametr confirm z requestu
		String confirm = request.getParameter(OSOBA_CONFIRM_PARAM);
		
		String message = "";
		
		// pokud byl parametr login v poradu nacten - nalezen v requestu, bude osoba s timto id
		// smazana
		if(id != null && id.length() != 0){
			
			logger.info("Parametr id nalezen");
			logger.info("Hledam osobu s id: " + id);
			
			Integer idInt;
			
			try{
				idInt = Integer.parseInt(id);
			}catch(NumberFormatException e){
				idInt = null;
				logger.fatal("Chyba pri nacitani parametru pozadavku - spatny format parametru id! ",e);
			}

			if(idInt != null){ // pokud se podarilo uspesne nacit parametr z url
				Osoba osoba = osobaManager.getOsobaById(idInt);
				
				//potvrzovaci zprava
				if(confirm == null || !confirm.equals("yes")){
					Map<String, Object> myModel = new HashMap<String, Object>();
					myModel.put("osoba", osoba);
					
					return new ModelAndView("smazatosobu", "model", myModel);
				}
				
				if(osoba != null){
					osobaManager.smazOsobu(osoba);
					message = "osoba smazana";
				}else{
					message = "Osoba nebyla nalezena.";
					return new ModelAndView("chyba", "message", message);
				}
			}

		}else{
			logger.info("Parametr nenalezen");
			message = "osoba k smazani nenalezena";
		}

		List<Osoba> osobyArrayList = new ArrayList<Osoba>();
		osobyArrayList = osobaManager.getOsoby();

		Map<String, Object> myModel = new HashMap<String, Object>();
		myModel.put("osoby", osobyArrayList);

		ModelAndView model = new ModelAndView("osobyprehled", "model", myModel);

		//zprava o smazani osoby
		model.addObject("deleteComplMsg", message);

		return model;
	}

	
	public void setOsobaManager(OsobaManager osobaManager) {
		this.osobaManager = osobaManager;
	}
}
