package cz.zcu.kiv.opencms.springmvcapp.validator;

import org.apache.commons.logging.Log;
import org.opencms.main.CmsLog;
import org.springframework.binding.message.MessageBuilder;
import org.springframework.binding.message.MessageContext;
import org.springframework.binding.validation.ValidationContext;
import cz.zcu.kiv.db.model.osoby.Osoba;
import java.util.regex.*;

/**
 * Trida pro validaci formulare s osobnimi daty osoby ve WebFlow
 * @author Jaroslav Pavuk
 *
 */
public class OsobaValidator {

	protected final Log logger = CmsLog.getLog(OsobaValidator.class);
	
	private static final String EMAIL_PATTERN = "\\b[a-zA-Z_0-9]+@[a-zA-Z_0-9]+\\.[a-zA-Z]{2,4}\\b";

	public void validateOsobniDataForm(Osoba osoba, ValidationContext context) {
		MessageContext messages = context.getMessageContext();

		//kontrola email adresy
		String email = osoba.getEmail();

		if(email != null && email.length() != 0){
			Pattern pattern = Pattern.compile(EMAIL_PATTERN);
			Matcher matcher = pattern.matcher(email);
			boolean found = false;

			while(matcher.find()) {
				found = true;
			}

			if(!found){
				messages.addMessage(new MessageBuilder().error().source("email").defaultText("Nespravny format pro email!").build());
			}
		}

		//kontrola loginu
		String login = osoba.getLogin();

		if(login == null || login.length() < 3){
			messages.addMessage(new MessageBuilder().error().source("login").defaultText("Login prilis kratky!").build());
		}

		//kontrola prijmeni
		String prijmeni = osoba.getPrijmeni();

		if(prijmeni == null || prijmeni.length() < 3){
			messages.addMessage(new MessageBuilder().error().source("prijmeni").defaultText("Prijmeni prilis kratke!").build());
		}

	}
}
