package cz.zcu.kiv.opencms.springmvcapp.validator;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.logging.Log;
import org.opencms.main.CmsLog;
import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import cz.zcu.kiv.db.model.osoby.Osoba;
import cz.zcu.kiv.opencms.springmvcapp.services.OsobaManager;


public class ZalozOsobuFormValidator implements Validator {

	protected final Log logger = CmsLog.getLog(ZalozOsobuFormValidator.class);
	private static final String EMAIL_PATTERN = "\\b[a-zA-Z_0-9]+@[a-zA-Z_0-9]+\\.[a-zA-Z]{2,4}\\b";
	
	private OsobaManager osobaManager;
	
	@Override
	public boolean supports(Class arg0) {
		return Osoba.class.isAssignableFrom(arg0);
	}

	@Override
	public void validate(Object arg0, Errors errors) {
		logger.info("Validating osoba form.");
		Osoba osoba = (Osoba) arg0;
		
		logger.debug("Osoba: " + osoba.toString());

		/* Je jmeno delsi nez 2 znaky? */
		if (osoba.getJmeno() != null && osoba.getJmeno().length() < 3) {
			errors.rejectValue("jmeno", "error.shortName", null, null);
			logger.info("Jmeno je kratsi nez 3 znaky!");
		}
		
		/* Je prijmeni delsi nez 2 znaky? */
		if (osoba.getPrijmeni() != null && osoba.getPrijmeni().length() < 3) {
			errors.rejectValue("prijmeni", "error.shortSurname", null, null);
			logger.info("Prijmeni je kratsi nez 3 znaky!");
		}


		String email = osoba.getEmail();		
		/* Je email validni? */
		if(email != null && email.length() != 0){
			Pattern pattern = Pattern.compile(EMAIL_PATTERN);
			Matcher matcher = pattern.matcher(email);
			boolean found = false;

			while(matcher.find()) {
				found = true;
			}

			if(!found){
				errors.rejectValue("email", "error.invalidEmail", null, null);
				logger.info("Email neni validni!");
			}
		}		
		
		/* Je login delsi nez 2 znaky? */
		if (osoba.getLogin() == null) {
			errors.rejectValue("login", "error.shortLogin", null, null);
			logger.info("Login je null!");
			osoba.setLogin(null);
		}
		
	}
	
	public void setOsobaManager(OsobaManager osobaManager) {
        this.osobaManager = osobaManager;
    }
	
}
